@@ -1,23 +1,13 @@
-from enum import Enum, unique
+from ts_t1_validator.models.enums.abstract_enum import AbstractEnum
 
 
-@unique
-class PercentageGoalTypeEnum(Enum):
+class PercentageGoalTypeEnum(AbstractEnum):
     CTR = "ctr"
     VCR = "vcr"
     VR = "viewability_rate"
 
-    @classmethod
-    def set(cls, value):
-        return cls(value) if any(value == item.value for item in cls) else None
 
-    @classmethod
-    def asList(cls) -> list:
-        return [x.value for x in list(cls)]
-
-
-@unique
-class FixedGoalTypeEnum(Enum):
+class FixedGoalTypeEnum(AbstractEnum):
     CPA = "cpa"
     CPC = "cpc"
     REACH = "reach"
@@ -25,17 +15,8 @@ class FixedGoalTypeEnum(Enum):
     SPEND = "spend"
     VCPM = "vcpm"
 
-    @classmethod
-    def set(cls, value):
-        return cls(value) if any(value == item.value for item in cls) else None
 
-    @classmethod
-    def asList(cls) -> list:
-        return [x.value for x in list(cls)]
-
-
-@unique
-class GoalTypeEnum(Enum):
+class GoalTypeEnum(AbstractEnum):
     CPA = "cpa"
     CPC = "cpc"
     REACH = "reach"
@@ -61,10 +42,6 @@ class GoalTypeEnum(Enum):
         """
         return self.value in PercentageGoalTypeEnum.asList()
 
-    @classmethod
-    def set(cls, value):
-        return cls(value) if any(value == item.value for item in cls) else cls(None)
-
     @classmethod
     def list(cls) -> str:
         return ", ".join("'{0}'".format(x.value) for x in cls if x.value is not None)
