@@ -60,17 +60,17 @@ class AbstractValidator(ABC):
         self.rules.append(rule)
 
     @abstractmethod
-    def build_rules_set(self):
+    def build_rules_set(self, *args, **kwargs):
         ...
 
-    def validate(self, dto: Dict) -> List:
+    def validate(self, *args, **kwargs) -> List:
         """
         Run validation
         :return: List
         """
         self.errors = list()
-        self.errors.extend(self.jsonSchemaValidation(dto))
-        self.build_rules_set(dto)
+        self.errors.extend(self.jsonSchemaValidation(kwargs.get("dto", {})))
+        self.build_rules_set(*args, **kwargs)
         for rule in self.rules:
             try:
                 rule.execute()
