@@ -5,10 +5,7 @@ from ts_t1_validator.models.enums.input_type import InputTypeEnum
 
 
 class BidsRule(ValidationRule):
-    def __init__(self, input_type, min_bid, max_bid):
-
-        assert type(input_type) is InputTypeEnum, "input_type should be InputTypeEnum"
-
+    def __init__(self, input_type: InputTypeEnum, min_bid, max_bid):
         self.input_type = input_type
         self.min_bid = min_bid
         self.max_bid = max_bid
