@@ -13,12 +13,6 @@ class FrequencyTypeRule(ValidationRule):
                  frequency_amount,
                  frequency_interval: FrequencyIntervalEnum,
                  input_type: InputTypeEnum):
-
-        assert type(frequency_type) is FrequencyTypeEnum, "frequency_type should be FrequencyTypeEnum type"
-        assert type(frequency_interval) is FrequencyIntervalEnum, \
-            "frequency_interval should be FrequencyIntervalEnum type"
-        assert type(input_type) is InputTypeEnum, "input_type should be InputTypeEnum type"
-
         self.frequency_optimization = frequency_optimization
         self.frequency_type = frequency_type
         self.frequency_amount = frequency_amount
